@@ -577,7 +577,7 @@ fn github_release_download_url(release_semver: &str) -> String {
 
 fn release_channel_download_url(release_channel: &str) -> String {
     format!(
-        "http://release.solana.com/{}/solana-release-{}.tar.bz2",
+        "https://release.solana.com/{}/solana-release-{}.tar.bz2",
         release_channel,
         crate::build_env::TARGET
     )
@@ -585,7 +585,7 @@ fn release_channel_download_url(release_channel: &str) -> String {
 
 fn release_channel_version_url(release_channel: &str) -> String {
     format!(
-        "http://release.solana.com/{}/solana-release-{}.yml",
+        "https://release.solana.com/{}/solana-release-{}.yml",
         release_channel,
         crate::build_env::TARGET
     )
